@@ -1,7 +1,7 @@
 """Module with classes and functions to work with JSON log data from the CARWatch App."""
 
-from biopsykit.carwatch_logs.log_data import LogData, LogDataInfo, subject_conditions, smartphone_models
-from biopsykit.carwatch_logs.log_statistics import LogStatistics
 from biopsykit.carwatch_logs import widgets
+from biopsykit.carwatch_logs.log_data import LogData, LogDataInfo, smartphone_models, subject_conditions
+from biopsykit.carwatch_logs.log_statistics import LogStatistics
 
 __all__ = ["LogData", "LogDataInfo", "LogStatistics", "smartphone_models", "subject_conditions", "widgets"]
