@@ -1,4 +1,4 @@
 """Module for the classification of (biopsychological) data."""
-from biopsykit.classification import utils, model_selection
+from biopsykit.classification import model_selection, utils
 
 __all__ = ["utils", "model_selection"]
