@@ -1,8 +1,8 @@
 """Module with utility functions for machine learning and classification applications."""
-from typing import Union, Tuple, Optional
+from typing import Optional, Tuple, Union
 
-import pandas as pd
 import numpy as np
+import pandas as pd
 from sklearn.pipeline import Pipeline
 
 __all__ = ["factorize_subject_id", "prepare_df_sklearn", "split_train_test", "strip_df", "strip_labels"]
