@@ -3,50 +3,49 @@
 The data is either taken from the local file system in case biopsykit was installed manually or the example data is
 downloaded into the local user folder.
 """
-from typing import Sequence, Dict, Optional, Tuple, Union
-from urllib.request import urlretrieve
 from pathlib import Path
-from tqdm.auto import tqdm
+from typing import Dict, Optional, Sequence, Tuple, Union
+from urllib.request import urlretrieve
 
 import pandas as pd
+from tqdm.auto import tqdm
 
-from biopsykit.utils.datatype_helper import (
-    is_saliva_mean_se_dataframe,
-    SubjectConditionDataFrame,
-    SalivaRawDataFrame,
-    SalivaMeanSeDataFrame,
-    HeartRatePhaseDict,
-    HeartRateSubjectDataDict,
-    SleepEndpointDataFrame,
-    _SalivaMeanSeDataFrame,
-)
-from biopsykit.utils.file_handling import mkdirs
 from biopsykit.io import (
-    load_subject_condition_list,
-    load_time_log,
-    load_questionnaire_data,
     load_long_format_csv,
     load_pandas_dict_excel,
+    load_questionnaire_data,
+    load_subject_condition_list,
+    load_time_log,
 )
 from biopsykit.io.carwatch_logs import load_log_one_subject
-from biopsykit.io.eeg import load_eeg_raw_muse
 from biopsykit.io.ecg import load_hr_phase_dict
+from biopsykit.io.eeg import load_eeg_raw_muse
 from biopsykit.io.nilspod import load_dataset_nilspod
-from biopsykit.io.saliva import load_saliva_wide_format, load_saliva_plate
+from biopsykit.io.saliva import load_saliva_plate, load_saliva_wide_format
 from biopsykit.io.sleep_analyzer import (
-    load_withings_sleep_analyzer_raw_folder,
     WITHINGS_RAW_DATA_SOURCES,
     load_withings_sleep_analyzer_raw_file,
+    load_withings_sleep_analyzer_raw_folder,
+    load_withings_sleep_analyzer_summary,
 )
-from biopsykit.io.sleep_analyzer import load_withings_sleep_analyzer_summary
 from biopsykit.utils._types import path_t
+from biopsykit.utils.datatype_helper import (
+    HeartRatePhaseDict,
+    HeartRateSubjectDataDict,
+    SalivaMeanSeDataFrame,
+    SalivaRawDataFrame,
+    SleepEndpointDataFrame,
+    SubjectConditionDataFrame,
+    _SalivaMeanSeDataFrame,
+    is_saliva_mean_se_dataframe,
+)
+from biopsykit.utils.file_handling import mkdirs
 
 _EXAMPLE_DATA_PATH_LOCAL = Path(__file__).parent.parent.parent.joinpath("example_data")
 _EXAMPLE_DATA_PATH_HOME = Path.home().joinpath(".biopsykit_data")
 _REMOTE_DATA_PATH = "https://raw.githubusercontent.com/mad-lab-fau/BioPsyKit/main/example_data/"
 
 __all__ = [
-    "get_file_path",
     "get_condition_list_example",
     "get_saliva_example_plate_format",
     "get_saliva_example",
@@ -55,9 +54,11 @@ __all__ = [
     "get_hr_result_sample",
     "get_hr_ensemble_sample",
     "get_hr_subject_data_dict_example",
+    "get_ecg_processing_results_path_example",
     "get_ecg_path_example",
     "get_ecg_example",
     "get_ecg_example_02",
+    "get_eeg_example",
     "get_sleep_analyzer_raw_file_unformatted",
     "get_sleep_analyzer_raw_file",
     "get_sleep_analyzer_raw_example",
@@ -69,6 +70,7 @@ __all__ = [
     "get_car_watch_log_data_example",
     "get_time_log_example",
     "get_questionnaire_example",
+    "get_questionnaire_example_wrong_range",
     "get_stats_example",
 ]
 
@@ -87,7 +89,7 @@ def _is_installed_manually() -> bool:
     return (_EXAMPLE_DATA_PATH_LOCAL / "__init__.py").is_file()
 
 
-def _get_data(file_name: str) -> path_t:
+def _get_data(file_name: str) -> path_t:  # pragma: no cover
     if _is_installed_manually():
         return _EXAMPLE_DATA_PATH_LOCAL.joinpath(file_name)
     path = _EXAMPLE_DATA_PATH_HOME.joinpath(file_name)
@@ -97,7 +99,7 @@ def _get_data(file_name: str) -> path_t:
     return _fetch_from_remote(file_name, path)
 
 
-def _fetch_from_remote(file_name: str, file_path: path_t) -> path_t:
+def _fetch_from_remote(file_name: str, file_path: path_t) -> path_t:  # pragma: no cover
     """Download remote dataset (helper function).
 
     Parameters
@@ -120,7 +122,7 @@ def _fetch_from_remote(file_name: str, file_path: path_t) -> path_t:
     return file_path
 
 
-def _tqdm_hook(t):
+def _tqdm_hook(t):  # pragma: no cover
     """Wrap tqdm instance."""
     last_b = [0]
 
@@ -133,27 +135,6 @@ def _tqdm_hook(t):
     return update_to
 
 
-def get_file_path(file_name: path_t) -> Optional[Path]:
-    """Return path to example data file.
-
-    Parameters
-    ----------
-    file_name : str or :class:`~pathlib.Path`
-        file name
-
-    Returns
-    -------
-    :class:`~pathlib.Path`
-        absolute path to file
-
-    """
-    file_path = _EXAMPLE_DATA_PATH_LOCAL.joinpath(file_name)
-    if file_path.is_file():
-        # file exists
-        return file_path
-    raise ValueError("File {} does not exist!".format(file_name))
-
-
 def get_condition_list_example() -> SubjectConditionDataFrame:
     """Return example data for subject condition assignment.
 
@@ -164,9 +145,7 @@ def get_condition_list_example() -> SubjectConditionDataFrame:
 
     """
     return load_subject_condition_list(
-        _EXAMPLE_DATA_PATH_LOCAL.joinpath("condition_list.csv"),
-        subject_col="subject",
-        condition_col="condition",
+        _get_data("condition_list.csv"), subject_col="subject", condition_col="condition"
     )
 
 
@@ -334,6 +313,24 @@ def get_ecg_path_example() -> path_t:
     return file_path.parent
 
 
+def get_ecg_processing_results_path_example() -> path_t:
+    """Return folder path to ECG processing results.
+
+    Returns
+    -------
+    :class:`~pathlib.Path` or str
+        path to folder with ECG processing results
+
+    """
+    subject_ids = ["Vp01", "Vp02"]
+    file_path = None
+    # ensure that folder exists and data in folder is available
+    for subject_id in subject_ids:
+        for file_type in ["hr_result", "rpeaks_result"]:
+            file_path = _get_data(f"ecg_processing_results/{file_type}_{subject_id}.xlsx")
+    return file_path.parent
+
+
 def get_ecg_example() -> Tuple[pd.DataFrame, float]:
     """Return raw ECG example data from one subject.
 
