@@ -179,6 +179,8 @@ def load_withings_sleep_analyzer_raw_file(
     data["start"] = pd.to_datetime(data["start"])
     # sort index
     data = data.set_index("start").sort_index()
+    # drop duplicate index values
+    data = data.loc[~data.index.duplicated()]
 
     # convert it into the right time zone
     data = data.groupby("start", group_keys=False).apply(_localize_time, timezone=timezone)
@@ -196,7 +198,7 @@ def load_withings_sleep_analyzer_raw_file(
     data_explode.columns = [data_source]
     # convert dtypes from object into numerical values
     data_explode = data_explode.astype(int)
-    # drop duplicate values
+    # drop duplicate index values
     data_explode = data_explode.loc[~data_explode.index.duplicated()]
 
     if split_into_nights:
