@@ -1,26 +1,25 @@
 """Module providing functions for plotting ECG data."""
-from typing import Optional, Sequence, Tuple, Dict, List
+from typing import TYPE_CHECKING, Dict, List, Optional, Sequence, Tuple
 
+import matplotlib as mpl
+import matplotlib.dates as mdates
+import matplotlib.gridspec as gs
+import matplotlib.pyplot as plt
+import matplotlib.ticker as mticks
+import neurokit2 as nk
 import numpy as np
 import pandas as pd
 import seaborn as sns
-import neurokit2 as nk
-
-import matplotlib as mpl
-import matplotlib.pyplot as plt
-import matplotlib.gridspec as gs
-import matplotlib.dates as mdates
-import matplotlib.ticker as mticks
-
 from neurokit2.hrv.hrv_frequency import _hrv_frequency_show
 from neurokit2.hrv.hrv_utils import _hrv_get_rri
 
 from biopsykit import colors
-from biopsykit.signals.ecg import EcgProcessor
 from biopsykit.signals.ecg.ecg import _assert_ecg_input
 from biopsykit.utils.array_handling import sanitize_input_1d
 from biopsykit.utils.datatype_helper import EcgResultDataFrame
 
+if TYPE_CHECKING:
+    from biopsykit.signals.ecg import EcgProcessor
 
 __all__ = [
     "ecg_plot",
@@ -467,6 +466,8 @@ def hrv_plot(
         plot Power Spectral Density (PSD) of RR intervals
 
     """
+    from biopsykit.signals.ecg import EcgProcessor  # pylint:disable=import-outside-toplevel
+
     _assert_ecg_input(ecg_processor, key, ecg_signal, rpeaks)
 
     title = kwargs.get("title", None)
